summaryrefslogtreecommitdiff
path: root/liveusb
diff options
context:
space:
mode:
Diffstat (limited to 'liveusb')
-rwxr-xr-xliveusb/airootfs/root/customize_airootfs.sh3
1 files changed, 2 insertions, 1 deletions
diff --git a/liveusb/airootfs/root/customize_airootfs.sh b/liveusb/airootfs/root/customize_airootfs.sh
index 2065be0..c7061f5 100755
--- a/liveusb/airootfs/root/customize_airootfs.sh
+++ b/liveusb/airootfs/root/customize_airootfs.sh
@@ -1,9 +1,10 @@
# Enable the vbox service
systemctl enable vboxservice
# Create the amenthes user and fix permissions on home dir
useradd -m -G wheel -s /bin/bash amenthes
chown -R amenthes:amenthes /home/amenthes
+sed -i 's/\(terminal=\)/\1lxterminal/' /home/amenthes/.config/libfm/libfm.conf
# Setup the lxdm config
sed -i 's/^# \(autologin=.*\)/\1/' /etc/lxdm/lxdm.conf # uncomment autlogin conf
@@ -1,9 +1,10 @@
# Enable the vbox service
systemctl enable vboxservice
-# Create the amenthes user and fix permissions on home dir
+# Create the amenthes user, fix permissions on home dir and default terminal
useradd -m -G wheel -s /bin/bash amenthes
chown -R amenthes:amenthes /home/amenthes